@@ -172,10 +172,6 @@ View::View(Plasma::Corona *corona, QScreen *targetScreen, bool byPassX11WM)
         if (m_positioner) {
             //! immediateSyncGeometry helps avoiding binding loops from containment qml side
             m_positioner->immediateSyncGeometry();
-            if (m_inStartup) {
-                m_inStartup = false;
-                m_positioner->slideInDuringStartup();
-            }
         }
 
         connect(this->containment(), SIGNAL(statusChanged(Plasma::Types::ItemStatus)), SLOT(statusChanged(Plasma::Types::ItemStatus)));
@@ -291,6 +287,24 @@ void View::init(Plasma::Containment *plasma_containment)
     connect(this, &View::activitiesChanged, this, &View::applyActivitiesToWindows);
     connect(m_positioner, &ViewPart::Positioner::winIdChanged, this, &View::applyActivitiesToWindows);
 
+    connect(this, &View::maxLengthChanged, this, [&]() {
+        if (m_inDelete) {
+            return;
+        }
+
+        emit availableScreenRectChangedFrom(this);
+        emit availableScreenRegionChangedFrom(this);
+    });
+
+    connect(this, &View::offsetChanged, this, [&]() {
+        if (m_inDelete ) {
+            return;
+        }
+
+        emit availableScreenRectChangedFrom(this);
+        emit availableScreenRegionChangedFrom(this);
+    });
+
     connect(this, &View::localGeometryChanged, this, [&]() {
         updateAbsoluteGeometry();
     });
@@ -407,6 +421,9 @@ void View::availableScreenRectChangedFromSlot(View *origin)
     }
 
     if (formFactor() == Plasma::Types::Vertical
+            && origin->formFactor() == Plasma::Types::Horizontal //! accept only horizontal views
+            && !(origin->location() == Plasma::Types::TopEdge && m_positioner->isStickedOnTopEdge()) //! ignore signals in such case
+            && !(origin->location() == Plasma::Types::BottomEdge && m_positioner->isStickedOnBottomEdge()) //! ignore signals in such case
             && origin->layout()
             && m_layout
             && origin->layout()->lastUsedActivity() == m_layout->lastUsedActivity()) {
@@ -660,8 +677,8 @@ void View::updateAbsoluteGeometry(bool bypassChecks)
         emit absoluteGeometryChanged(m_absoluteGeometry);
     }
 
-    //! this is needed in order to update correctly the screenGeometries
-    if (visibility() && corona() && visibility()->mode() == Types::AlwaysVisible) {
+    if ((m_absoluteGeometry != absGeometry) || bypassChecks) {
+        //! inform others such as neighbour vertical views that new geometries are applied
         //! main use of BYPASSCKECKS is from Positioner when the view changes screens
         emit availableScreenRectChangedFrom(this);
         emit availableScreenRegionChangedFrom(this);
@@ -1342,7 +1359,8 @@ Latte::Data::View View::data() const
         vdata.screen = containment()->lastScreen();
     }
 
-    vdata.screenEdgeMargin = m_screenEdgeMargin;
+    //!screen edge margin can be more accurate in the config file
+    vdata.screenEdgeMargin = m_screenEdgeMargin > 0 ? m_screenEdgeMargin : containment()->config().group("General").readEntry("screenEdgeMargin", (int)-1);
 
     vdata.edge = location();
     vdata.maxLength = m_maxLength * 100;
@@ -1716,6 +1734,7 @@ void View::restoreConfig()
     //! Send changed signals at the end in order to be sure that saveConfig
     //! wont rewrite default/invalid values
     emit alignmentChanged();
+    emit nameChanged();
     emit onPrimaryChanged();
     emit byPassWMChanged();
 }
